@@ -42,14 +42,14 @@ from .params import Form
 SCHEDULE_LOG = 'schedule.log'
 
 
-class Step(OrderedObject):
+class Step(Object):
     """ Basic execution unit.
     It should defines its Input, Output
     and define a run method.
     """
 
     def __init__(self, **kwargs):
-        OrderedObject.__init__(self, **kwargs)
+        Object.__init__(self, **kwargs)
         self._prerequisites = CsvList()  # which steps needs to be done first
         self.status = String()
         self.initTime = String()
@@ -1206,7 +1206,7 @@ class Protocol(Step):
         for attrName in attributes:
             attr = getattr(self, attrName)
             self.mapper.delete(attr)
-            self.deleteAttribute(attrName)
+            delattr(self, attrName)
 
         self._outputs.clear()
         self.mapper.store(self._outputs)
@@ -1220,7 +1220,7 @@ class Protocol(Step):
     def deleteOutput(self, output):
         attrName = self.findAttributeName(output)
         self.mapper.delete(output)
-        self.deleteAttribute(attrName)
+        delattr(self,attrName)
         if attrName in self._outputs:
             self._outputs.remove(attrName)
         self.mapper.store(self._outputs)
@@ -1510,22 +1510,25 @@ class Protocol(Step):
         if not lastLines:
             lastLines = int(os.environ.get('PROT_LOGS_LAST_LINES', 20))
 
-        if not all(os.path.exists(p) for p in self.getLogPaths()):
+        # Get stdout
+        stdoutFn =self.getLogPaths()[0]
+
+        if not os.path.exists(stdoutFn):
             return []
 
-        self.__openLogsFiles('r')
-        iterlen = lambda it: sum(1 for _ in it)
-        numLines = iterlen(self.__fOut)
+        with  open(stdoutFn, 'r') as stdout:
 
-        lastLines = min(lastLines, numLines)
-        sk = numLines - lastLines
-        sk = max(sk, 0)
+            iterlen = lambda it: sum(1 for _ in it)
+            numLines = iterlen(stdout)
 
-        self.__fOut.seek(0, 0)
-        output = [l.strip('\n') for k, l in enumerate(self.__fOut)
-                  if k >= sk]
-        self.__closeLogsFiles()
-        return output
+            lastLines = min(lastLines, numLines)
+            sk = numLines - lastLines
+            sk = max(sk, 0)
+
+            stdout.seek(0, 0)
+            output = [l.strip('\n') for k, l in enumerate(stdout)
+                      if k >= sk]
+            return output
 
     def warning(self, message, redirectStandard=True):
         self._log.warning(message, redirectStandard)
